import multer from 'multer';
import { Request as RequestUtil } from '../util/index.js';
import { AssistantInstaller } from '../service/index.js';
const memoryStorage = multer({ storage: multer.memoryStorage() });
class AssistantInstallerRoutes {
    register(app) {
        app.get('/installer-version', async (req, res) => {
            try {
                const response = await AssistantInstaller.list();
                res.status(200).send(response);
            }
            catch (err) {
                RequestUtil.handleResponseError(res, err);
            }
        });
        app.post('/installer-version/:client/:version', memoryStorage.single('file'), async (req, res) => {
            try {
                if (req.file) {
                    const response = await AssistantInstaller.create(req.file, RequestUtil.getAllParams(req));
                    res.status(200).send(response);
                }
                else {
                    res.status(500).send({ error: 'file not informed' });
                }
            }
            catch (err) {
                RequestUtil.handleResponseError(res, err);
            }
        });
        app.post('/installer-version/restore-backup', async (req, res) => {
            try {
                const response = await AssistantInstaller.restoreBackup(RequestUtil.getAllParams(req));
                res.status(200).send(response);
            }
            catch (err) {
                RequestUtil.handleResponseError(res, err);
            }
        });
        app.delete('/installer-version', async (req, res) => {
            try {
                const response = await AssistantInstaller.remove(RequestUtil.getAllParams(req));
                res.status(200).send(response);
            }
            catch (err) {
                RequestUtil.handleResponseError(res, err);
            }
        });
    }
}
const instance = new AssistantInstallerRoutes();
export { instance as AssistantInstallerRoutes };
export default instance;
