import { PrismaClient } from '../db/index.js';
import { Docker } from './index.js';
class Server {
    async create(params) {
        const { name, port, protocol, host, deployEnabled } = params;
        const data = {
            name,
            protocol,
            host,
            port,
            deployEnabled,
        };
        const prismaResponse = await PrismaClient.server.create({ data });
        Docker.addInstance(name, deployEnabled, { protocol, host, port });
        return prismaResponse;
    }
    async list() {
        return PrismaClient.server.findMany();
    }
    async remove({ name, serversToRemove }) {
        const servers = Array.isArray(serversToRemove)
            ? serversToRemove.map(({ id }) => id || '')
            : [];
        const where = { id: { in: servers } };
        if (name) {
            const response = await PrismaClient.server.delete({ where: { name } });
            Docker.removeInstance(name);
            return response;
        }
        if (Array.isArray(serversToRemove)) {
            const response = PrismaClient.server.deleteMany({ where });
            Docker.removeInstances(serversToRemove?.map(({ name: serverName }) => serverName));
            return response;
        }
        return { status: 'error', message: 'Server name not found' };
    }
    async modify(params) {
        const { id, ...paramsToUpdate } = params;
        const response = await PrismaClient.server.update({
            where: { id },
            data: paramsToUpdate,
        });
        const serverInstance = Docker.getInstance({ serverName: paramsToUpdate.name });
        if (!Array.isArray(serverInstance)) {
            serverInstance.deployEnabled = paramsToUpdate.deployEnabled || serverInstance.deployEnabled;
        }
        return response;
    }
}
const instance = new Server();
export { instance as Server };
export default instance;
